﻿using Microsoft.VisualStudio.TestTools.UnitTesting;
using Nest;

namespace Search.Library.Tests
{
    [TestClass]
    public class SearchTests
    {
        private ElasticClient _client;

        [TestInitialize]
        public void OnInit()
        {
            _client = new ElasticConfiguration().CreatElasticClient();
            // just for testing.  Should use custom index name.
            var indexExists = _client.IndexExists(new IndexExistsRequest(Indices.Parse(ElasticConfiguration.DefaultIndexName)));
            if (indexExists.Exists)
            {
                _client.DeleteIndex(new DeleteIndexDescriptor(Indices.Parse(ElasticConfiguration.DefaultIndexName)));
            }
            _client.Refresh(new RefreshRequest(Indices.All));
            new ElasticConfiguration().SetupMappings();
        }

        [TestMethod]
        public void Should_Create_Mappings()
        {
            var config = new ElasticConfiguration();
            config.SetupMappings();
        }

        [TestMethod]
        public void Should_Add_Data()
        {
            _client = new ElasticConfiguration().CreatElasticClient();
            var loc = new Location
            {
                Type = "STANDARD",
                Coordinates = new Coordinates
                {
                    Lat = 30,
                    Lon = 40
                },
                Latitude = 30,
                CityId = 1,
                EstimatedPopulation = 23,
                State = "GA",
                City = "Atlanta",
                Zip = "30000",
                Country = "USA",
                AreaCodes = "33333 44444",
                County = "Gwinnett",
                Longitude = 40,
                WorldRegion = "North America"
            };
            _client.Index(loc, descriptor =>
            {
                descriptor.Index("default");
                return descriptor;
            });
        }
    }
}
